aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorGravatar Szymon Tomasz Stefanek2015-09-06 23:34:30 +0200
committerGravatar Szymon Tomasz Stefanek2015-09-06 23:34:30 +0200
commit61e9646aec5b44db1eb86c99e627fce69f0c489c (patch)
tree997394460dd05cf675ea74c233327fafebf1d517
parentMerge pull request #1552 from uNiversaI/Cant-Help_Myself (diff)
parentVarious SVN -> Git chnages and README updates (diff)
downloadKVIrc-61e9646aec5b44db1eb86c99e627fce69f0c489c.tar.gz
KVIrc-61e9646aec5b44db1eb86c99e627fce69f0c489c.tar.bz2
KVIrc-61e9646aec5b44db1eb86c99e627fce69f0c489c.zip
Merge pull request #1549 from uNiversaI/Spring-Clean
Various SVN -> Git changes and general README/docs updates
-rw-r--r--CMakeLists.txt2
-rw-r--r--ChangeLog2
-rw-r--r--admin/makedist.sh2
-rw-r--r--cmake/Doxyfile.cmake2
-rw-r--r--doc/CMakeLists.txt2
-rw-r--r--doc/FAQ70
-rw-r--r--doc/INSTALL921
-rw-r--r--doc/INSTALL-MacOS.txt18
-rw-r--r--doc/INSTALL-Win32.txt80
-rw-r--r--doc/accelerator.keys.txt91
-rw-r--r--doc/addon.howto.txt15
-rw-r--r--doc/firefox.hack.txt8
-rw-r--r--doc/hackers.guide.txt8
-rw-r--r--doc/translations.howto.txt19
-rw-r--r--po/core/kvirc/kvirc.pot4
-rw-r--r--src/kvirc/kernel/KviApplication.cpp2
-rw-r--r--src/kvirc/ui/KviStatusBarApplet.cpp10
17 files changed, 630 insertions, 626 deletions
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 70a320ef9..0f5fbc78c 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -87,7 +87,7 @@ set(LIB_SUFFIX
CACHE STRING "Define suffix of directory name (32/64)"
)
-# Get revision number from SVN
+# Get revision number from Git
set(MANUAL_REVISION
CACHE STRING "Manually set the revision number"
)
diff --git a/ChangeLog b/ChangeLog
index a7c147f45..2ea39772a 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,6 +1,6 @@
This is KVIrc's changelog. It tipically lists new added features and changes that modify
KVIrc's previous behaviour. For a more detailed (and up to date) log, point your browser at:
-https://svn.kvirc.de/kvirc/timeline
+https://github.com/kvirc/KVIrc/commits/master
Update: 20141104
diff --git a/admin/makedist.sh b/admin/makedist.sh
index 8341cb2c9..6b296d488 100644
--- a/admin/makedist.sh
+++ b/admin/makedist.sh
@@ -150,7 +150,7 @@ if [ "${DOMD5SUM}" = "yes" ]; then
fi
#################################################################################################
-# Cleanup the exported svn tree
+# Cleanup the exported Git branch
echo "Removing target directory..."
rm -rf "${TEMPSRCDIR}"
diff --git a/cmake/Doxyfile.cmake b/cmake/Doxyfile.cmake
index 1dedef93e..56b75bda1 100644
--- a/cmake/Doxyfile.cmake
+++ b/cmake/Doxyfile.cmake
@@ -785,7 +785,7 @@ EXCLUDE_SYMLINKS = NO
# Note that the wildcards are matched against the file with absolute path, so to
# exclude all test directories for example use the pattern */test/*
-EXCLUDE_PATTERNS = */.svn/*
+EXCLUDE_PATTERNS = */.git/*
# The EXCLUDE_SYMBOLS tag can be used to specify one or more symbol names
# (namespaces, classes, functions, etc.) that should be excluded from the
diff --git a/doc/CMakeLists.txt b/doc/CMakeLists.txt
index ac3f06c17..aace062c6 100644
--- a/doc/CMakeLists.txt
+++ b/doc/CMakeLists.txt
@@ -25,7 +25,7 @@ set(howto
if(PERL_FOUND)
# The userdocs target is in the normal build process and rebuilds the documentation
- # only when the revision number changes. This is useful for svn users and package users.
+ # only when the revision number changes. This is useful for Git users and package users.
# The docs target is standalone and explicitly builds the documentation (useful for developers)
diff --git a/doc/FAQ b/doc/FAQ
index a5f0565b0..bdbe43cb8 100644
--- a/doc/FAQ
+++ b/doc/FAQ
@@ -6,7 +6,7 @@
2. COMPILATION
-2.1 I can't compile kvirc from svn, what's wrong?
+2.1 I can't compile KVIrc from Git, what's wrong?
2.2 Internal Compiler Errors ?
@@ -27,7 +27,7 @@
4.6 /me doesn't support the '$' character, what's wrong ?
4.7 /me doesn't support the '"' (double quote) character, what's wrong ?
4.8 /me can't contain the ';' character, what's wrong ?
-4.9 I try to do a /whois on nick blah\ but i get the reply for blah (without the slash)
+4.9 I try to do a /whois on nick blah\ but I get the reply for blah (without the slash)
4.10 What is AVATAR protocol ? Is there any documentation about it ?
4.11 The log files seem to be saved randomly, when I open a log
I can see only a part of the text that actually should be there
@@ -63,7 +63,7 @@
7. CRASHES
7.1 What the heck is a gdb stack trace and how do I get it ?
-7.2 KVIrc hangs up, but doesn't crash. How do i report debug information ?
+7.2 KVIrc hangs up, but doesn't crash. How do I report debug information ?
7.3 KVIrc exits by itself or simply "disappears" without any apparent reason.
7.4 KVIrc dies when using alias(identify){ identify password; }
@@ -96,22 +96,23 @@
the KVIrc sources with the KDE library changes we choose not to do it.
If you wish to contribute some code that better integrates KVIrc with
KDE you're welcome to do so: we will happily accept your patches as long
- as you promise to mantain them :)
+ as you promise to maintain them :)
--------------------------------------------------------------------------------
2. COMPILATION
--------------------------------------------------------------------------------
-2.1 I can't compile kvirc from svn, what's wrong?
+2.1 I can't compile KVIrc from Git, what's wrong?
Have you checked the requirements ?
*Carefully* read the INSTALL file that comes with the distribution:
- it contains the information to solve 95% of the problems that
+ it contains the information which solves 95% of the problems that
you may encounter. You may also try digging in our mailing list
archive: many problems have been solved there.
- If you still can't get it to work please either subscribe to the KVIrc
- mailing list (see www.kvirc.net) and report the problem there or join #kvirc
+ If you still can't get it to work, please either subscribe to the KVIrc
+ mailing list (see www.kvirc.net) and report the problem there. Alternatively
+ open a issue at https://github.com/kvirc/KVIrc/issues or join #kvirc
on Freenode and ask the channel members for a hint.
@@ -129,7 +130,7 @@
out 5-6 of them daily. Usually it is solved by simply restarting the "make" command.
If it doesn't go away or if it gets really frequent and annoying you might try to upgrade the compiler.
2) A memory corruption: this is really frequent: one of your memory banks is spitting random bytes
- sometimes. Usually the problems come out under heavy system load (kernel, KDE or kvirc compilation for example).
+ sometimes. Usually the problems come out under heavy system load (kernel, KDE or KVIrc compilation for example).
You can check for memory corruption by trying different RAM modules (or removing them one at a time to discover
the broken bank). You can also try a program called memtest and a kernel
patch that can force the broken memory banks to be ignored by the kernel (allocated permanently to a dummy kernel task).
@@ -160,12 +161,12 @@
4. IRC
-------------------------------------------------------------------------------
-4.1 How do i join a channel ?
+4.1 How do I join a channel ?
Type "/join #channelname"
-4.2 How do i autojoin channels?
+4.2 How do I autojoin channels?
There are many ways to do it.
For example:
@@ -180,7 +181,7 @@
Now click OK and you're done: you have just created a handler for an event.
Reconnect to a server and KVIrc will autojoin the channels that you have selected.
Another option (nicer, if you use several servers) is to go to the servers options
- page and click the button labeled 'Advanced' on the entry for the single server.
+ page and click the button labelled 'Advanced' on the entry for the single server.
There is a server-specific "On connect execute..." event.
@@ -192,7 +193,7 @@
"Advanced...". In the dialog that appears there is a NickServ tab
on that you can add your identification rules. Adding a rule
should be straightforward (if you stop the mouse over an item you will likely get a small
- tool tip with the explaination). Each rule is composed of:
+ tool tip with the explanation). Each rule is composed of:
- the nickname that is being identified: the rule will be applied only
when your current nickname corresponds to this one.
- a nick server user mask that must be matched by the NickServ user
@@ -264,12 +265,12 @@
# ping6 ipv6.google.com
- Is the IPV6 support enabled in your kvirc executable ?
+ Is the IPV6 support enabled in your KVIrc executable ?
To find it out, try
/echo $features
- in the KVIrc commandline. You should get a comma separated list of
+ in the KVIrc command line. You should get a comma separated list of
features compiled in the executable. If the list contains "IPv6" then
the support is compiled in, otherwise you must check your compilation
stage to guess what went wrong.
@@ -281,12 +282,12 @@
4.6 /me doesn't support the '$' character, what's wrong ?
- This is NOT a bug : this is a feature : kvirc supports (and substitutes!) variables in all the commands.
+ This is NOT a bug : this is a feature : KVIrc supports (and substitutes!) variables in all the commands.
You can escape your $ sign by using the backslash character:
/me has gained \$100
- Otherwise, you can use friendly commandline mode, where special symbols are not interpreted. Just click the green
+ Otherwise, you can use friendly command line mode, where special symbols are not interpreted. Just click the green
arrow next to the input field and then click the KVS icon.
@@ -298,29 +299,29 @@
/me feels a bit \"foo\"
- Otherwise, you can use friendly commandline mode, where special symbols are not interpreted. Just click the green
+ Otherwise, you can use friendly command line mode, where special symbols are not interpreted. Just click the green
arrow next to the input field and then click the KVS icon.
4.8 /me can't contain the ';' character, what's wrong ?
- This is NOT a bug : this is a feature : kvirc supports multiple commands on a single line and uses ';' as a command
+ This is NOT a bug : this is a feature : KVIrc supports multiple commands on a single line and uses ';' as a command
separator. You can escape your ';' sign by using the backslash character:
/me is hungry \;)
- Otherwise, you can use friendly commandline mode, where special symbols are not interpreted. Just click the green
+ Otherwise, you can use friendly command line mode, where special symbols are not interpreted. Just click the green
arrow next to the input field and then click the KVS icon.
-4.9 I try to do a /whois on nick blah\ but i get the reply for blah (without the slash)
+4.9 I try to do a /whois on nick blah\ but I get the reply for blah (without the slash)
In KVIrc /whois is a scripting command and the nickname is a command parameter.
In scripting commands the backslash is a special character with several "escape"
meanings. To include a literal backslash inside a parameter you MUST double it,
thus the correct command to issue is /whois blah\\
- Otherwise, you can use friendly commandline mode, where special symbols are not interpreted. Just click the green
+ Otherwise, you can use friendly command line mode, where special symbols are not interpreted. Just click the green
arrow next to the input field and then click the KVS icon.
@@ -342,7 +343,7 @@
prefix but is a simple file name. The remote users request the avatars
by issuing a DCC GET command. This is an useful but secondary extension
and can be ignored by simple implementations. If you need more information
- about this method please write to pragma at kvirc dot net.
+ about this method please write to pragma at KVIrc dot net.
4.11 The log files seem to be saved randomly, when I open a log
@@ -379,8 +380,6 @@
This option should be used ONLY IF you have problems without.
-
-
-------------------------------------------------------------------------------
5. ADVANCED IRC FEATURES
-------------------------------------------------------------------------------
@@ -395,7 +394,7 @@
/echo $features
- in the KVIrc commandline. If "SSL" is not in the list then you must go back
+ in the KVIrc command line. If "SSL" is not in the list then you must go back
to the compilation phase and see what went wrong.
@@ -441,7 +440,7 @@
and then choose one of the available engines.
The Mircryption engine is an implementation of the mircryption protocol and
supports both ECB and CBC mode. There is also a wide variety of Rijndael based encryption
- engies as well as some funky other text transform tricks.
+ engines as well as some funky other text transform tricks.
Most of the engines will need a pair of keys to encrypt and decrypt text
and in most cases you will use the same key for both encrypting and
decrypting. In the particular case of Mircryption you can enable
@@ -604,14 +603,14 @@
run "C:\\path\\to\\your\\browser.exe" "$0"
- as url handler for the protocol you're interested in (maybe in all).
+ as URL handler for the protocol you're interested in (maybe in all).
Please note the double backslashes (a single backslash is an escaping character)
Suepahfly suggests to use
rundll32 url.dll,FileProtocolHandler "$0"
- as url handler to open the url in the default windows browser.
+ as URL handler to open the URL in the default windows browser.
-------------------------------------------------------------------------------
@@ -621,7 +620,7 @@
7.1 What the heck is a gdb stack trace and how do I get it ?
A gdb stack trace is a "photography" of the state of the KVIrc internals
- taken when a certain event has occured. The most common event
+ taken when a certain event has occurred. The most common event
is a program crash (Segmentation Fault).
The stack trace helps (or even allows) the developers to locate the
crash cause in the program sources.
@@ -632,7 +631,7 @@
- Have a working installation of gdb (the gnu debugger)
This is usually available on your distribution cd
and you may already have it installed.
- - Run KVirc:
+ - Run KVIrc:
# gdb kvirc
When the gdb prompt appears write:
# (gdb) run -f
@@ -641,10 +640,10 @@
# (gdb) bt
The text you see is the stack trace you wanted :)
Copy+Paste and create a new bug ticket in the web bugtracker
- (you can find a link on the kvirc website).
+ (you can find a link on the KVIrc website).
-7.2 KVIrc hangs up, but doesn't crash. How do i report debug information ?
+7.2 KVIrc hangs up, but doesn't crash. How do I report debug information ?
Use gdb to get a stack trace as in answer to question 7.1.
Since your KVIrc doesn't crash you will have to interrupt the execution
@@ -665,20 +664,19 @@
that once for all and fix your script.
-
-------------------------------------------------------------------------------
8. SCRIPTING / ADDONS
-------------------------------------------------------------------------------
8.1 Trying to load a script i get a "can't load the module 'script'" error.
- Full version of the error (this is for linux, may vary on windows/other os):
+ Full version of the error (this is for Linux, may vary on Windows/other OS):
---
[KVS] Runtime Error: Module command call failed: can't load the module 'script':
QLibrary::load_sys: Cannot load /usr/local/share/kvirc/4.0/modules/libkviscript.so
(/usr/local/share/kvirc/4.0/modules/libkviscript.so: no such file or directory)
---
The script you are trying to load is calling an old KVIrc interface. Probably the
- script was created for kvirc <= 3.2, and has not been updated to work on newer
+ script was created for KVIrc <= 3.2, and has not been updated to work on newer
versions. The "script" module interface has been renamed to "addon" between 3.2.0.99
and 3.2.4; the new "addon" module exports all the old "script" interfaces, so
converting the script should be quite easy.
diff --git a/doc/INSTALL b/doc/INSTALL
index 8316c2975..f34e9ca5b 100644
--- a/doc/INSTALL
+++ b/doc/INSTALL
@@ -1,244 +1,219 @@
-Elvio Basello (HelLViS69) Mon Nov 17 2008
-###############################################################################
-General notes for the installation of the 4.2 release of KVIrc
-###############################################################################
+-------------------------------------------------------------------------------
+ Table of contents
+-------------------------------------------------------------------------------
- This document contains the procedures to compile and install
- the version 4.2 of KVIrc.
+ 1. Introduction
+ 2. Dependencies and requirements
+ 3. Configuring the environment
+ 4. Getting and updating the source code:
+ 5. Configuring KVIrc
+ 6. Interactive cmake KVIrc configuration
+ 7. Compiling KVIrc
+ 8. Compiling on Mac OS X
+ 9. Compiling on Win32
+ 10. Hacker installation
+ 11. Creating a KVIrc package
-###############################################################################
-# 0. Table of contents
-###############################################################################
+-------------------------------------------------------------------------------
+ 1. Introduction
+-------------------------------------------------------------------------------
- 1. Introduction
- 2. Minimal requirements
- 3. Configuring the environment
- 4. Interactive mode
- 5. Compiling
- 6. Compiling on MacOS X
- 7. Compiling on Win32
- 8. Hacker-level installation
- 9. Creating a KVIrc package
+ This document contains the procedures to clone KVIrc's source code
+ configure your environment, configure, compile and install KVIrc.
-###############################################################################
-# 1. Introduction
-###############################################################################
+ If you have found this document in a binary distribution then
+ KVIrc has been probably already installed by your favorite package
+ manager and maybe something is not working as expected. In this case
+ this document and the accompanying F.A.Q. can help you determining
+ the issue.
- This document contains the procedures to compile and install
- the version 4.2 of KVIrc.
+ If you have found this document in a source distribution or you
+ have downloaded it by using Git or downloaded tarball then well...
+ this is a standard INSTALL file :)
+
+ Note: It isn't practical to cover all Linux distributions in this doc.
+
+ This doc provides fully working instructions for Ubuntu or variants.
+ Compiling KVIrc in your preferred Linux distributions is possible,
+ provided the minimum required dependencies are met.
- If you have found this document in a binary distribution then
- KVIrc has been probably already installed by your favorite package
- manager and maybe something is not working as expected. In this case
- this document and the accompanying FAQ can help you in guessing
- what's wrong.
+ From here on in this doc refer to "Ubuntu or variants", where variants
+ are distributions which are Ubuntu derivatives.
+
+ Note: If anyone could find the time to test KVIrc with ICC please let us know!)
- If you have found this document in a source distribution or you
- have downloaded it by using SVN then well...
- this is a standard INSTALL file :)
+-------------------------------------------------------------------------------
+ 2. Dependencies and requirements:
+-------------------------------------------------------------------------------
+"
+ KVIrc requires the development libraries it depends on below.
+ Some of these libraries are optional but they all extend KVIrc functionality.
+ Dependencies marked as preferred, while not required for compiling KVIrc,
+ these are suggested that their installation should be chosen by default.
+ Where OpenSSL is concerned, you should check it is legal to use cryptographic
+ libraries in your Country.
+ In order to get the source code configure and compile KVIrc you will require:
-###############################################################################
-# 2. Minimal requirements:
-###############################################################################
+ - C++ compiler ............ (Required)
+ - CMake ................... (Required) >= 2.8.12.2
+ - Enchant ................. (Optional)
+ - git-core ................ (Preferred)
+ - Qt GUI Toolkit .......... (Required) >= 4.8
+ - Pthread implementation .. (Required)
+ - Python .................. (Optional)
+ - Phonon framework......... (Preferred)
+ - pkg-config .............. (Required)
+ - GSM speech compressor ... (Optional)
+ - ZLib .................... (Required) >= 1.2.8
+ - KDE ..................... (Optional)
+ - GNU gettext ............. (Optional)
+ - Perl .................... (Optional) >= 5.004
+ - OpenSSL ................. (Preferred)
+ - X Rendering Extension ... (Required)
+ - X11 client-side library . (Required)
- In order to compile KVIrc 4.2 you need at least these software:
- - Qt GUI Toolkit 4.6 ore newer - http://www.qtsoftware.com
- - CMake 2.6.4 or newer - http://www.cmake.org
- - C++ compiler, such as g++ - http://gcc.gnu.org (btw: we'd be glad if any-
- one could find the time to test KVIrc with ICC!)
- - Pthread implementation
- - ZLib - http://www.zlib.org
- - KDE (Optional) - http://www.kde.org
- - GNU gettext (Optional) - http://www.gnu.org/software/gettext
- - Perl (Optional) - http://www.perl.com
- - OpenSSL (Optional) - http://www.openssl.org
+ For Ubuntu or variant distributions the complete list of dependencies
+ and installation command is:
+
+ $ sudo apt-get install build-essential cmake git-core libenchant-dev
+ libgettextpo-dev libgsm1-dev libperl-dev libpthread-stubs0-dev
+ libssl-dev libx11-dev libxrender-dev pkg-config python-dev zlib1g-dev
+
+ Additionally if you are compiling KVIRC with Qt4.x install:
+
+ $ sudo apt-get install libphonon-dev libqt4-dev libqtwebkit-dev
- #
- # Qt GUI Toolkit
- #
+ Additionally if you are compiling KVIRC with Qt5.x install:
+
+ $ sudo apt-get install libphonon4qt5-dev libphonon4qt5experimental-dev
+ libphonon4qt5experimental-dev libqt5svg5-dev libqt5webkit5-dev
+ libqt5x11extras5-dev qtbase5-dev qtmultimedia5-dev
+
+ Note: You can install QT5.x and QT4.x libraries side by side.
+ You may want to only install a preferred Qt version instead of both at same time.
+ Then to try a different QT version, uninstall one before installing the other, e.g.
- You need the qt development package. Install it with your distribution
- package manager. On ubuntu, for instance, the package is called libqt4-dev.
+ $ sudo apt-get remove --purge <package> <package> <package> etc.
+ $ sudo apt-get install <package> <package> <package> etc.
+
+-------------------------------------------------------------------------------
+ 3. Configuring the environment:
+-------------------------------------------------------------------------------
- If your distribution is sane installing the development package
- will set up everything properly. However you might need the following
- paragraphs in case something goes wrong.
+ If your distribution is sane, installing the development packages should set up
+ your environment variables correctly. You will know that something is wrong when
+ you run CMake, the configuration output will complain if paths are not found.
+
+ If cmake configuration terminates successfully you can skip step 3.
+ However when this is not the case you may need to export the path variables manually.
+ e.g. $QTDIR.
+
+ Note: Where x is either 4 or 5)
- Before running CMake make sure that the environment variable $QTDIR
- points to the right location. This will help in finding the correct version
- of Qt.
+ For x86 e.g.
- You might eventually set it with the command:
+ $ export QTDIR=/usr/lib/qtx
- # export QTDIR="your Qt dir"
+ For x86_64 e.g.
+
+ $ export QTDIR=/usr/lib/x86_64-linux-gnu/qtx
+
+ Note: If you have multiple distinct versions of the same Qtx.x installed
+ and want to use a specific version, exporting QTDIR won't suffice, since the
+ CMake module searching for Qtx.x uses qmake itself to determine the Qtx library dir.
+
+ You can set your $PATH variable to have CMake using your specified Qtx.x version:
- On my system, Qt is installed in /usr/lib/qt4, thus I actually execute:
+ $ PATH=/opt/qtx.x/bin/:$PATH cmake ..
+
+ Note: See step [5. Configuring KVIrc] for supported cmake configuration flags.
+ The trailing dots are required when you build out-of-source
+ or CMake will likely fail.
- # export QTDIR=/usr/lib/qt4
+ ## KDE (Optional)
- To check if you are using the right version of Qt, simply run:
+ If you want to compile the KDE integration support, you obviously need KDE.
+ The kdelibs package should suffice.
- # qmake -v
+ So before running CMake make sure that the environment variable $KDEDIR
+ points to the right location.
- On my system the output is:
+ You might eventually set it with the command:
- QMake version 2.01a
- Using Qt version 4.7.2 in /usr/lib64/qt/lib
+ $ export KDEDIR="your kde dir"
- If you have multiple versions of Qt4 installed in your system and want to
- use a specific version, exporting QTDIR won't suffice. Since the CMake
- module searching for Qt4 uses qmake itself to determine the Qt4 library dir,
- you can set your $PATH variable to have CMake using
- your preferred qmake version:
+ Where KDE is for e.g. installed in /usr use:
- # PATH=/opt/qt4.7/bin/:$PATH cmake ..
+ $ export KDEDIR=/usr
+
+ Note: Compiling with KDE4 support enabled will force KVIrc to
+ link against the Qt4 version that KDE4 is using. This may lead to problems
+ in linking. Disabling KDE4 support is the only known solution at the moment.
+ In this case override the Qt libraries used when running KVIrc:
- Please note that compiling with KDE4 support enabled will force KVIrc to
- link against the Qt4 version that KDE4 is using. This may lead to problems
- in linking. Disabling KDE4 support is the only known solution at the moment.
- Note also that in this case you'll need to override the Qt libraries used
- when running KVIrc:
+ $ LD_LIBRARY_PATH=/opt/qt4.8/lib/ kvirc4
- # LD_LIBRARY_PATH=/opt/qt4.7/lib/ kvirc4
- #
- # CMake
- #
+ ## Pthread implementation (required)
- This is usually included in nowadays distros.
- To check which CMake you have, simply run:
+ This is usually included in your distribution and is probably already
+ installed. In Ubuntu or variants the library is libpthread-stubs0-dev.
+ The library is called libpthread.so. You can search for it using the "find"
+ or, at your option, "locate" command.
- # cmake --version
+0. $ find / -name libpthread*
- On my system the ouput is:
+1. $ locate -i "libpthread*"
- # cmake version 2.6-patch 4
+ ## GNU gettext (Optional)
- #
- # C++ compiler
- #
+ If you use KVIrc in a language other than English, then you need
+ the GNU gettext package. In particular KVIrc uses msgfmt.
- You need a decent C++ compiler. Usually under linux it is GCC from GNU
- tools.
- It is preferred to use GCC 4.x, but GCC 3.4.6 works as well. Older version
- *might* work.
- ICC is *neither* officially supported *nor* tested. Reports are welcome,
- though.
- To check your GCC version, just run:
+ This is usually included in your distribution and is probably already installed.
+ In Ubuntu or variants this library is libgettextpo-dev.
+ If your distro is not Ubuntu or variant you can check it by running:
- # gcc -v
+ $ msgfmt --version
- The output on my system is:
+ KVIrc will not complain if the command above is missing. It will just skip
+ the creation of the translation files. See the cmake configuration output.
- Reading specs from /usr/lib64/gcc/x86_64-slackware-linux/4.3.3/specs
- Target: x86_64-slackware-linux
- Configured with: ../gcc-4.3.3/configure --prefix=/usr --libdir=/usr/lib64
---enable-shared --enable-bootstrap
---enable-languages=ada,c,c++,fortran,java,objc --enable-threads=posix
---enable-checking=release --with-system-zlib --disable-libunwind-exceptions
---enable-__cxa_atexit --enable-libssp --with-gnu-ld --verbose
---disable-multilib --target=x86_64-slackware-linux
---build=x86_64-slackware-linux --host=x86_64-slackware-linux
- Thread model: posix
- gcc version 4.3.3 (GCC)
+ ## Perl (Optional)
- #
- # Pthread implementation
- #
+ If you want to generate the on-line documentation you'll also need perl.
- This is usually included in your distribution and is probably already
- installed. The library is called libpthread.so.
- You can look for it using the "find" or, at your option, "locate" command:
+ Note: The way external software can embed perl has changed between perl version
+ 5.8 and 5.10. KVIrc should play nice with perl as of version 5.004 and
+ higher, but 5.10 is strongly recommended, since future updates can break
+ backwards compatibility.
- # find / -name libpthread.so
- ## or ##
- # locate libpthread.so
+ If you want perl scripting support to be compiled, you need a working perl
+ installation. Your libperl.so MUST be compiled with the multiplicity option.
+ You can check it with:
- On my system the output is:
+ $ perl -V
- # /usr/lib/libpthread.so
- If you don't have it (CMake will tell you), you can download it from your
- favorite GNU mirror.
- The configure script will also fail if the library is hidden somewhere in
- your system (eg. not in /lib, /usr/lib or /usr/local/lib). In this case,
- you should probably move it.
+ ## OpenSSL (Preferred)
- #
- # KDE (Optional)
- #
+ If you want the secure socket layer (SSL) support to be compiled, you need
+ the OpenSSL development library, in Ubuntu or variants its libssl-dev
- If you want to compile the KDE integration support, you obviously need KDE.
- The kdelibs package should suffice.
- So before running CMake make sure that the environment variable $KDEDIR
- points to the right location.
+ ## GSM (Optional)
- You might eventually set it with the command:
+ If you want DCC VOICE to support the gsm codec,
+ you need a recent copy of libgsm. This is not strictly required
+ at compile time since KVIrc will look for the library at run-time
+ and only if the DCC VOICE with the gsm codec is requested.
+ You can check for libgsm using the 'find' or 'locate' command.
- # export KDEDIR="your kde dir"
+0. $ find / -name libgsm*
- In my case KDE is installed in /usr so I use
-
- # export KDEDIR=/usr
-
-
- #
- # GNU gettext (Optional)
- #
-
- If you want the translations to non-english languages to work, then you need
- the GNU gettext package. In particular KVIrc uses the msgfmt program.
-
- This is usually included in your distribution and is probably already
- installed. You can check it by running:
-
- # msgfmt --version
-
- KVIrc will not complain if the command above is missing. It will just skip
- the creation of the translation files.
- If the command above fails, then you need to install the gettext package if
- you want any other language than English.
-
-
- #
- # Perl (Optional)
- #
-
- If you want to generate the on-line documentation you'll also need perl. Any
- version will do (I guess).
-
- If you want PERL SCRIPTING support to be compiled, you need a working perl
- installation. Your libperl.so MUST be compiled with the MULTIPLICITY option.
- You can check it with perl -V
- The way external software can embed perl has changed between perl version
- 5.8 and 5.10. KVIrc should play nice with perl as of version 5.004 and
- higher, but 5.10 is strongly recommended, since future updates can break
- backwards compatibility.
-
-
- #
- # OpenSSL (Optional)
- #
-
- If you want the secure socket layer (SSL) support to be compiled, you need
- the OpenSSL library and headers. (libssl.so and openssl/ssl.h)
-
- - (Optional) If you want DCC VOICE to support the gsm codec,
- you need a recent copy of libgsm. This is not strictly required
- at compile time since KVIrc will look for the library at run-time
- and only if the DCC VOICE with the gsm codec is requested.
- You can check for libgsm using the 'find' or 'locate' command.
-
- # find / -name libgsm*
- ## or ##
- # locate -i "libgsm*"
-
- The output should be something like
-
- # /usr/lib/libgsm.so
+1. $ locate -i "libgsm*"
This library is included in most distributions.
Some distros ship only the static version of the library "libgsm.a".
@@ -246,353 +221,383 @@ General notes for the installation of the 4.2 release of KVIrc
to "/usr/lib/libgsm.a", you might create the shared library manually
by running:
- # cd /usr/lib
- # ld --whole-archive -shared -o libgsm.so.1 libgsm.a
- # ln -s libgsm.so.1 libgsm.so
- # ldconfig
+ $ cd /usr/lib
+ $ ld --whole-archive -shared -o libgsm.so.1 libgsm.a
+ $ ln -s libgsm.so.1 libgsm.so
+ $ ldconfig
+
+ Notes:
+ 1. This won't work if the library was compiled without -fPIE.
+ 2. Files in /usr/lib should really be managed by package manager of the distro.
+ Whenever package containing libgsm.a upgrades, the manually created libgsm.so stays old.
+ 3. The distribution can provide a better way to install libgsm.so.
+ e.g. in Gentoo many packages have static-libs USE-flag which tells the package manager
+ to install not only .so files, but also .a (which is kinda the reverse, but the point still stands)
- If you don't have it installed at all, you might want to have a look
- on your distribution CD, or download it from the web.
+ ## Phonon framework - (Preferred)
+
+ If you want the /snd plugin to play various audio formats,
+ you either need the phonon framework, a running ESounD daemon,
+ or a reasonably recent audiofile library.
+ Without these KVIrc will be only able to play *.au files.
+ - You will need the dynamic linker interface library libdl.so.
- - (Optional) If you want the /snd plugin to play various audio formats,
- you either need a running artsd (nowadays replaced by the phonon
- framework), a running ESounD daemon, or a reasonably recent
- audiofile library. Without these KVIrc will be only able to play *.au
- files.
+ This is usually installed on your system, so don't care until configure
+ complains about it. Some system have the interface builtin in libc. The
+ configure script can detect this.
+
+-------------------------------------------------------------------------------
+ 4. Getting and updating the source code:
+-------------------------------------------------------------------------------
- - You need the dynamic linker interface library libdl.so.
+ The KVIrc development code is located at https://github.com/kvirc/KVIrc
+ There are several ways to get KVIrc's source code, if you compile often,
+ Preferable way is to clone the repository, this allows for the most flexibility.
+ Alternatively if you prefer. you can also download a tarball.
+
+ $ mkdir /home/setup && cd /home/setup
+0. $ git clone https://github.com/kvirc/KVIrc.git
- This is usually installed on your system, so don't care until configure
- complains about it. Some system have the interface builtin in libc. The
- configure script can detect this.
+ Keeping the git clone up-to-date is simple.
+
+ $ git pull --rebase upstream master
+ Or download the latest release tarball
-###############################################################################
-# 3. Configuring the environment
-###############################################################################
+ $ mkdir /home/setup && cd /home/setup
+1. $ wget https://github.com/kvirc/KVIrc/archive/master.tar.gz -O kvirc.git.tar.gz
- Since KVIrc 4.2 uses CMake as build system, we have to use it to create
- the Makefile's rules for make program.
- To do it, we encourage the "out-of-source" building: build all files
- without dirtying the sources directory.
- # mkdir release
- # cd release
- # cmake [your options] ..
+-------------------------------------------------------------------------------
+ 5. Configuring KVIrc
+-------------------------------------------------------------------------------
- In this way you have just created an out-of-source environment which is
- clean at the beginning and can be changed afterwards, as well as a clean
- source directory.
- Note that the final dots are required or CMake will NOT create the right
- environment.
+ Since KVIrc 4.2 uses CMake as build system, we have to use it to create
+ the Makefile's rules for make program.
+ To do it, we encourage the "out-of-source" building: build all files
+ without dirtying the sources directory.
- The CMake rules support some flags. If you don't specify them, CMake will
- try to guess a good environment for you. :)
- To use these flags, you have to pass a bool value or a string.
- For example, to install KVIrc in /usr instead of /usr/local and to disable
- Phonon support, the command looks like:
+ $ cd /home/setup && mkdir release
+ $ cd release
+ $ cmake [your options] ..
- # cmake -DCMAKE_INSTALL_PREFIX=/usr -DWANT_PHONON=0 ..
+ In this way you have just created an out-of-source environment which is
+ clean at the beginning and can be changed afterwards, as well as a clean
+ source directory.
- Here's a list with explainations:
+ Note: The trailing dots are required when you build out-of-source e.g.
+ or CMake will likely fail.
- -DWANT_QT4 (default: OFF)
- Prefer Qt4 over Qt5.
- If both Qt4 and Qt5 supported versions are found on the system, Qt5
- is preferred and used for compilation. Enabling this option changes
- this behaviour, forcing Qt4 to be used.
+ The CMake rules support some flags. If you don't specify them, CMake will
+ try to guess a good environment for you. :)
+ To use these flags, you have to pass a bool value or a string.
+ e.g. To install KVIrc in /usr instead of /usr/local and to disable
+ Phonon support, the command looks like:
- -DWANT_DEBUG (default: OFF)
- When enabled, compiles the executable with debug symbols.
- Useful for reporting bugs.
+ $ cmake -DCMAKE_INSTALL_PREFIX=/usr -DWANT_PHONON=0 ..
- -DWANT_STRIP (default: OFF)
- Available only if debug is disabled, this flag disables objects
- stripping before installation.
- (Object stripping discards symbols from object files, lowering their
- size on disk, at the expense of more complicated or rather impossible
- debugging.)
+ -DWANT_QT4= (default: OFF)
+ Prefer Qt4 over Qt5.
+ If both Qt4 and Qt5 supported versions are found on the system, Qt5
+ is preferred and used for compilation. Enabling this option changes
+ this behaviour, forcing Qt4 to be used.
- -DWANT_VERBOSE (default: OFF)
- Generate verbose output when compiling.
- (Note: this will be deactivated when using a job setting higher than 1
- with gmake. I.e., make -j2 will *not* show any verbose compilation
- output.)
+ -DWANT_DEBUG= (default: OFF)
+ When enabled, compiles the executable with debug symbols.
+ Useful for reporting bugs.
- -DCMAKE_INSTALL_PREFIX=PATH (default: a system-dependant directory)
- This will install all stuff under PATH directory.
+ -DWANT_STRIP= (default: OFF)
+ Available only if debug is disabled, this flag disables objects
+ stripping before installation.
+ (Object stripping discards symbols from object files, lowering their
+ size on disk, at the expense of more complicated or rather impossible
+ debugging.)
- -DLIB_SUFFIX=SUFFIX (default: empty)
- This will install libkvilib and KVIrc modules to
- ${CMAKE_INSTALL_PREFIX}/lib${LIB_SUFFIX}
- directory. It defaults to an empty suffix.
- Mainly used for 64bit distros.
+ -DWANT_VERBOSE= (default: OFF)
+ Generate verbose output when compiling.
+ Note: this will be deactivated when using a job setting higher than 1
+ with gmake. i.e., make -j2 will *not* show verbose compilation output.
- -DMANDIR=DIRECTORY (default: $CMAKE_INSTALL_PREFIX/share/man)
- This will install man pages to DIRECTORY.
+ -DCMAKE_INSTALL_PREFIX=PATH 0 (default: a system-dependant directory)
+ This will install all stuff under PATH directory.
- -DWANT_COEXISTENCE (default: OFF)
- If enabled, appends version information to KVIrc and libkvilib, so that
- different KVIrc versions can co-exist on the same system.
+ -DLIB_SUFFIX=SUFFIX - (default: empty)
+ This will install libkvilib and KVIrc modules to
+ ${CMAKE_INSTALL_PREFIX}/lib${LIB_SUFFIX}
+ directory. It defaults to an empty suffix.
+ Mainly used for x86_64 architectures.
- -DWANT_ENV_FLAGS (default: OFF)
- When enabled, KVIrc install rules won't try to figure out and set
- CMAKE_C(XX)_FLAGS. Instead, it will let CMake use the ones taken
- from environment variables.
- Activating this flag will override the value of -DWANT_DEBUG.
+ -DMANDIR=DIRECTORY (default: $CMAKE_INSTALL_PREFIX/share/man)
+ This will install man pages to DIRECTORY.
- -DCMAKE_INSTALL_PREFIX_INITIALIZED_TO_DEFAULT (default: OFF, not cached)
- This will re-initialize the installation path to a good default.
- Following compilations should use the correct path value cached by
- CMake.
- This flag is useful to solve MacOS X install problems.
+ -DWANT_COEXISTENCE= (default: OFF)
+ If enabled, appends version information to KVIrc and libkvilib, so that
+ different KVIrc versions can co-exist on the same system.
- -DWANT_UNIVERSAL_BINARY (default: OFF)
- Enables or disables the compilation of universal binaries
- for the MacOS X platform.
+ -DWANT_ENV_FLAGS= (default: OFF)
+ When enabled, KVIrc install rules wont try to figure out and set
+ CMAKE_C(XX)_FLAGS. Instead, it will let CMake use the ones taken
+ from environment variables.
+ Activating this flag will override the value of -DWANT_DEBUG.
- -DWANT_PHONON (default: ON)
- Enables or disables Phonon audio backend support.
+ -DCMAKE_INSTALL_PREFIX_INITIALIZED_TO_DEFAULT= (default: OFF, not cached)
+ This will re-initialize the installation path to a good default.
+ Following compilations should use the correct path value cached by CMake.
+ This flag is useful to solve MacOS X install problems.
- -DWANT_OSS (default: ON)
- Enables or disables OpenSoundSystem audio backend support.
- If disabled, Audiofile support will be disabled as well.
+ -DWANT_UNIVERSAL_BINARY= (default: OFF)
+ Enables or disables the compilation of universal binaries
+ for the MacOS X platform.
- -DWANT_AUDIOFILE (default: ON)
- Enables or disables Audiofile audio backend support.
+ -DWANT_PHONON= (default: ON)
+ Enables or disables Phonon audio backend support.
- -DWANT_ESD (default: ON)
- Enables or disables ESounD audio backend support.
+ -DWANT_OSS= (default: ON)
+ Enables or disables OpenSoundSystem audio backend support.
+ If disabled, Audiofile support will be disabled as well.
- -DWANT_QTDBUS (default: ON)
- Enables or disables Qt-DBus support.
+ -DWANT_AUDIOFILE= (default: ON)
+ Enables or disables Audiofile audio backend support.
- -DWANT_QTWEBKIT (default: ON)
- Enables or disables Qt-WebKit support.
+ -DWANT_ESD= (default: ON)
+ Enables or disables ESounD audio backend support.
- -DWANT_KDE4 (default: ON)
- Enables or disables KDE4 support.
+ -DWANT_QTDBUS= (default: ON)
+ Enables or disables Qt-DBus support.
- -DWANT_OPENSSL (default: ON)
- Enables or disables the crypto functions support using OpenSSL.
+ -DWANT_QTWEBKIT= (default: ON)
+ Enables or disables Qt-WebKit support.
- -DWANT_CRYPT (default: ON)
- Enables or disables the cryptographic engines and the whole cryptography/text
- transformation support. Produces a slightly smaller executable.
- You will lack features, though.
+ -DWANT_KDE4 (default: ON)
+ Enables or disables KDE4 support.
- -DWANT_IPV6 (default: ON)
- Enables or disables the IPv6 support.
- Even if you have a plain IPv4-only connection, you might want to
- keep the IPv6 support. This way you will be able to resolve
- IPv6 hostnames.
+ -DWANT_OPENSSL= (default: ON)
+ Enables or disables the crypto functions support using OpenSSL.
- -DWANT_TRANSPARENCY (default: ON)
- This option enables or disbales pseudo and real transparency support.
- The pseudo-transparency support makes the KVIrc windows
- look like semi-transparent (this is NOT real transparency, it is
- just a neat-looking hack). Transparency uses compositing and needs
- proper hardware support to work.
- If KDE support is enabled, KVIrc will have an option that
- makes all windows use a faded KDE desktop background image
- as background. Without KDE support you will be able to choose
- a fake background image and use it as background. (You can still
- choose your desktop wallpaper, this will (more-or-less) work with
- all window managers).
- It is cool-looking but usually eats some memory and makes the
- executable slightly bigger, when enabled. Especially when moving
- objects around, CPU consumption may get high as well.
- You can thus disable transparency here.
+ -DWANT_CRYPT (default: ON)
+ Enables or disables the cryptographic engines and the whole cryptography/text
+ transformation support. Produces a slightly smaller executable.
+ You will lack features, though.
- -DWANT_GTKSTYLE (default: OFF)
- QGtkStyle is a QT backend that uses native Gtk widgets. In recent Gtk
- versions some insane choices are hardcoded and impossible to workaround
- (example: icons can't be shown in menus, label background color is
- fixed). By default we disable QGtkStyle since it messes up with KVIrc
- internal themeing engine creating bad problems (like unreadable white
- text on a white background). Some users wants to use it anyway and
- sometimes we like to check if gtk developers quit smoking pot, so this
- option let you enable the QGtkStyle engine.
- Please don't report any theme-related bug if you enabled this option:
- we already know it's broken, but nobody's gonna fix it.
+ -DWANT_IPV6 (default: ON)
+ Enables or disables the IPv6 support.
+ Even if you have a plain IPv4-only connection, you might want to
+ keep the IPv6 support. This way you will be able to resolve
+ IPv6 hostnames.
- -DWANT_PERL (default: ON)
- Enables or disables perl support.
- You will not be able to use Perl scripts inside of KVIrc.
- You still can execute Perl scripts outside of KVIrc, i.e. with
- the exec() command.
- Note that perl support will be checked anyway, and used to generate
- the documentation if present.
+ -DWANT_TRANSPARENCY (default: ON)
+ This option enables or disables pseudo and real transparency support.
+ The pseudo-transparency support makes the KVIrc windows
+ look like semi-transparent (this is NOT real transparency, it is
+ just a neat-looking hack). Transparency uses compositing and needs
+ proper hardware support to work.
+ If KDE support is enabled, KVIrc will have an option that
+ makes all windows use a faded KDE desktop background image
+ as background. Without KDE support you will be able to choose
+ a fake background image and use it as background. (You can still
+ choose your desktop wallpaper, this will (more-or-less) work with
+ all window managers).
+ It is cool-looking but usually eats some memory and makes the
+ executable slightly bigger, when enabled. Especially when moving
+ objects around, CPU consumption may get high as well.
+ You can thus disable transparency here.
- -DWANT_PYTHON (default: ON)
- Enables or disables python support.
- You will not be able to use Python scripts inside of KVIrc.
+ -DWANT_GTKSTYLE (default: OFF)
+ QGtkStyle is a QT backend that uses native Gtk widgets. In recent Gtk
+ versions some insane choices are hardcoded and impossible to workaround
+ (example: icons can't be shown in menus, label background color is
+ fixed). By default we disable QGtkStyle since it messes up with KVIrc
+ internal theme engine creating issues (like unreadable white
+ text on a white background). Some users wants to use it anyway and
+ sometimes we like to check if gtk developers quit smoking pot, so this
+ option let you enable the QGtkStyle engine.
+ Please don't report any theme-related bug if you enabled this option:
+ we already know it's broken, but nobody's gonna fix it.
- -DWANT_IPC (default: ON)
- Enables or disables support for inter-process communication.
- You will not be able to send remote commands to running
- KVIrc sessions. This basically means that every time you run
- the KVIrc executable, a new session will be started.
- If you don't use this switch, a new session will be started
- only if no session is running on the same display or
- "new session" has been forced by a commandline switch.
- If a session is already running, the commandline will be
- passed to that session via IPC (X-event-based communication).
- This option saves the KVIrc executable some KByte in size,
- so if you're really, really short in memory, you might use it,
- otherwise, IPC is a nice feature.
+ -DWANT_PERL (default: ON)
+ Enables or disables perl support.
+ You will not be able to use Perl scripts inside of KVIrc.
+ You still can execute Perl scripts outside of KVIrc, i.e. with
+ the exec() command.
+ Note that perl support will be checked anyway, and used to generate
+ the documentation if present.
- -DWANT_GETTEXT (default: ON)
- Enables or disables the use of GetText to generate translation files.
+ -DWANT_PYTHON (default: ON)
+ Enables or disables python support.
+ You will not be able to use Python scripts inside of KVIrc.
- -DWANT_DOXYGEN (default: ON)
- Enables or disables developers docs generation through Doxygen.
+ -DWANT_IPC (default: ON)
+ Enables or disables support for inter-process communication.
+ You will not be able to send remote commands to running
+ KVIrc sessions. This basically means that every time you run
+ the KVIrc executable, a new session will be started.
+ If you don't use this switch, a new session will be started
+ only if no session is running on the same display or
+ "new session" has been forced by a commandline switch.
+ If a session is already running, the commandline will be
+ passed to that session via IPC (X-event-based communication).
+ This option saves the KVIrc executable some KByte in size,
+ so if you're really, really short in memory, you might use it,
+ otherwise, IPC is a nice feature.
- -DWANT_GSM (default: ON)
- Enables or disables the usage of the GSM library. This will
- disable the DCC VOICE gsm codec but might help when the
- compilation stops complaining of something related to GSM. :)
+ -DWANT_GETTEXT (default: ON)
+ Enables or disables the use of GetText to generate translation files.
- -DWANT_IGNORE_SIGALARM (default: OFF)
- Under Solaris, both usleep() and threads implementation are based on
- SIGALARM. KVIrc uses both, and this could lead to some spontaneous
- application quits. This option enables a workaround for this problem.
+ -DWANT_DOXYGEN (default: ON)
+ Enables or disables developers docs generation through Doxygen.
- -DWANT_DCC_VOICE (default: ON)
- Enables or disables the DCC VOICE sound support. This might help
- if you have problems in compilation of src/modules/dcc/voice.cpp.
- It will disable the sound support (and thus render DCC VOICE unusable).
+ -DWANT_GSM (default: ON)
+ Enables or disables the usage of the GSM library. This will
+ disable the DCC VOICE gsm codec but might help when the
+ compilation stops complaining of something related to GSM. :)
- -DWANT_DCC_VIDEO (default: OFF)
- Enables or disables EXPERIMENTAL DCC VIDEO support.
+ -DWANT_IGNORE_SIGALARM (default: OFF)
+ Under Solaris, both usleep() and threads implementation are based on
+ SIGALARM. KVIrc uses both, and this could lead to some spontaneous
+ application quits. This option enables a workaround for this problem.
- -DWANT_OGG_THEORA (default: OFF)
- Enables or disables EXPERIMENTAL Ogg/Theora Support for dcc video.
+ -DWANT_DCC_VOICE (default: ON)
+ Enables or disables the DCC VOICE sound support. This might help
+ if you have problems in compilation of src/modules/dcc/voice.cpp.
+ It will disable the sound support (and thus render DCC VOICE unusable).
- -DWANT_DCC_CANVAS (default: OFF)
- Enables or disables OBSOLETE DCC CANVAS support.
+ -DWANT_DCC_VIDEO (default: OFF)
+ Enables or disables EXPERIMENTAL DCC VIDEO support.
- -DWANT_MEMORY_PROFILE (default: OFF)
- Enables or disables memory allocation profiling.
- Don't set it, unless you are a developer and know what you are doing.
- It will have high impact on executable size and most noteably speed.
- Please do not use this.
+ -DWANT_OGG_THEORA (default: OFF)
+ Enables or disables EXPERIMENTAL Ogg/Theora Support for dcc video.
- -DWANT_MEMORY_CHECKS (default: OFF)
- Enables or disables malloc() memory checks. This will print a nice
- message if your system goes out of memory.
- It can't save you from buying new RAM, but at least you will know that
- your system went out of memory and it is not a proper KVIrc fault.
- Most systems do actually already notice you when you are out of RAM
- (i.e. Linux and the OOM killer.)
- Most probably you will not need to enable this flag.
+ -DWANT_DCC_CANVAS (default: OFF)
+ Enables or disables OBSOLETE DCC CANVAS support.
- -DMANUAL_REVISION (default: empty)
- Manually set a revision number if subversion is not found on your
- system.
- This is useful mostly on windows.
- Please do not specify useless information here, as it will make
- debugging harder and you won't profit from it.
+ -DWANT_SPELLCHECKER (default: ON)
+ Compile Spell-Checker Support
- -DWANT_PIZZA (default: OFF)
- Add some pizza for dinner. :)
+ -DWANT_MEMORY_PROFILE (default: OFF)
+ Enables or disables memory allocation profiling.
+ Don't set it, unless you are a developer and know what you are doing.
+ It will have high impact on executable size and most noteably speed.
+ Please do not use this.
- -DWANT_BEER (default: OFF)
- Add some beers to chat. :)
+ -DWANT_MEMORY_CHECKS (default: OFF)
+ Enables or disables malloc() memory checks. This will print a nice
+ message if your system goes out of memory.
+ It can't save you from buying new RAM, but at least you will know that
+ your system went out of memory and it is not a proper KVIrc fault.
+ Most systems do actually already notice you when you are out of RAM
+ (i.e. Linux and the OOM killer.)
+ Most probably you will not need to enable this flag.
-###############################################################################
-# 4. Interactive mode
-###############################################################################
+ -DMANUAL_REVISION (default: empty)
+ Manually set a revision number if subversion is not found on your
+ system.
+ This is useful mostly on windows.
+ Please do not specify useless information here, as it will make
+ debugging harder and you won't profit from it.
- The CMake build system provide also an interactive mode to configure
- the environment before compiling.
- Again, we encourage the "out-of-source" building: build all files
- without dirting the sources directory.
+ -DWANT_PIZZA (default: OFF)
+ Add some pizza for dinner. :)
- # mkdir release
- # cd release
- # ccmake ..
+ -DWANT_BEER (default: OFF)
+ Add some beers to chat. :)
- Now you're in interactive mode, just follow the instructions on screen
- to configure your compilation environment.
+-------------------------------------------------------------------------------
+ 6. Interactive cmake KVIrc configuration
+-------------------------------------------------------------------------------
-###############################################################################
-# 5. Compiling
-###############################################################################
+ The CMake build system provide also an interactive mode to configure
+ the environment before compiling.
+ Again, we encourage the "out-of-source" building: build all files
+ without dirting the sources directory.
- This step is easy:
- Cross your fingers and run:
+ $ mkdir release
+ $ cd release
+ $ ccmake ..
- # make
+ Now you're in interactive mode, just follow the instructions on screen
+ to configure your compilation environment.
- If your make is not a GNU make (this happens on FreeBSD for example) you
- should use "gmake" instead.
- The compilation process will take from 6-7 minutes to several hours
- depending on the machine capabilities and load.
- If you have a slow cpu but have a couple of computers in a lan you might
- consider using distcc to distribute the compilation.
+-------------------------------------------------------------------------------
+ 7. Compiling
+-------------------------------------------------------------------------------
- Once the compilation has been succesfull, run:
+ This step is easy:
+ Cross your fingers and run:
- # make install
+0. $ make
+
+ Or to speed up compilation you can add more jobs to make with -jN
+
+1. $ make -j2
+
+ If your make is not a GNU make (this happens on FreeBSD for example) you
+ should use "gmake" instead.
+ The compilation process will take from 6-7 minutes to several hours
+ depending on the machine capabilities and load.
+ If you have a slow CPU but have a couple of computers in a LAN you might
+ consider using distcc to distribute the compilation.
+
+ Once the compilation has been successfully, run:
+
+ $ sudo make install
- Same as above: use "gmake install" if your make is not GNU make.
+ Same as above: use "gmake install" if your make is not GNU make.
- This will install the executable in /usr/local/bin (if you don't have
- specified a different -DCMAKE_INSTALL_PREFIX option in the CMake rules),
- the libraries in /usr/local/lib (if you don't have specified a different
- -DLIB_SUFFIX option in the CMake rules) and the shared data in
- /usr/local/share/kvirc.
+ This will install the executable in /usr/local/bin (if you haven't
+ specified a different -DCMAKE_INSTALL_PREFIX option in the CMake rules),
+ the libraries in /usr/local/lib (if you don't have specified a different
+ -DLIB_SUFFIX option in the CMake rules) and the shared data in
+ /usr/local/share/kvirc.
- Make sure that /usr/local/lib is in your /etc/ld.so.conf. If it isn't,
- put it in there and run:
+ Make sure that /usr/local/lib is in your /etc/ld.so.conf. If it isn't,
+ put it in there and run:
- # ldconfig
+ $ ldconfig
with super-user privileges.
- If you have decided to use the KDE support the installation might have
- placed all these files in your $KDEDIR tree instead of /usr/local.
- In this case you should be OK since KDE requires its library dir to be
- in /etc/ld.so.conf.
+ If you have decided to use the KDE support the installation might have
+ placed all these files in your $KDEDIR tree instead of /usr/local.
+ In this case you should be OK since KDE requires its library dir to be
+ in /etc/ld.so.conf.
-###############################################################################
-# 6. Compiling on MacOS X
-###############################################################################
+-------------------------------------------------------------------------------
+ 8. Compiling on MacOS X
+-------------------------------------------------------------------------------
- There is a detailed compilation and installation HOWTO for MacOS X systems
- located in the doc directory. It's named INSTALL-MacOS.txt.
+ There is a detailed compilation and installation HOWTO for MacOS X systems
+ located in the doc directory. It's named INSTALL-MacOS.txt.
-###############################################################################
-# 7. Compiling on Win32
-###############################################################################
+-------------------------------------------------------------------------------
+ 9. Compiling on Win32
+-------------------------------------------------------------------------------
- There is a detailed compilation and installation HOWTO for Win32 systems
- located in the doc directory. It's named INSTALL-Win32.txt.
+ There is a detailed compilation and installation HOWTO for Win32 systems
+ located in the doc directory. It's named INSTALL-Win32.txt.
-###############################################################################
-# 8. Hacker installation:
-###############################################################################
+-------------------------------------------------------------------------------
+ 10. Hacker installation:
+-------------------------------------------------------------------------------
# mkdir release
# cd release
# cmake ..
# make install
-###############################################################################
-# 9. Creating a KVIrc package
-###############################################################################
+-------------------------------------------------------------------------------
+ 11. Creating a KVIrc package
+-------------------------------------------------------------------------------
- CMake supports DESTDIR argument.
- So, if you want to make a package for your distro, you simply have to pass
- it at "make install" stage: your install files will go to the chosen path.
+ CMake supports DESTDIR argument.
+ So, if you want to make a package for your distribution, you simply have to pass
+ it at "make install" stage: your install files will go to the chosen path.
- # make install DESTDIR=/tmp/kvirc-4.2
+ $ make install DESTDIR=/tmp/kvirc-4.3
- After this step, just follow your distribution's rules to make a good
- package for the distro you're running.
+ After this step, just follow your distribution's rules to make a good
+ package for the distro you're running.
- Alternatively, you can try the experimental CPack support included in
- CMakelist.txt to build a package. In this case, please refer to the CPack
- documentation.
+ Alternatively, you can try the experimental CPack support included in
+ CMakelist.txt to build a package. In this case, please refer to the CPack
+ documentation.
diff --git a/doc/INSTALL-MacOS.txt b/doc/INSTALL-MacOS.txt
index b7b489fac..4ccf9139d 100644
--- a/doc/INSTALL-MacOS.txt
+++ b/doc/INSTALL-MacOS.txt
@@ -2,7 +2,7 @@ Original documentation by Thomas Kalla, 17.09.2009
Last updated by Fabio Bas, 2012.04.07
#########################
-This document contains step-by-step instructions for compiling KVIrc4 from SVN
+This document contains step-by-step instructions for compiling KVIrc4 from Git
sources on a Mac OS X system. Due to changed prerequisites and compilation
system, this compilation howto does not apply to older versions of KVirc.
@@ -79,7 +79,7 @@ Please note that when using XCode >= 4.3 you need at least cmake 2.8.8.
1) Get the KVIrc sources:
- # svn co https://svn.kvirc.de/svn/trunk/kvirc
+ # git clone https://github.com/kvirc/KVIrc.git
2) Build! :-)
@@ -87,22 +87,22 @@ Two IMPORTANT hints before you start:
Notes for x86_64 arch:
---
-Currently i found no way to successfully add scripting support for Perl and
+Currently I found no way to successfully add scripting support for Perl and
Python on Intel 64-bit macs. When compiled in, they both mess up with the
target architecture and leads to linking failures. Perl can be safely use
to generate the documentation, anyway.
I found KVIrc crashing when compiled in debug mode with QtDbus enabled and
-no dbus daemon running, so i advice you to disable it.
+no dbus daemon running, so I advice you to disable it.
Additionally, if you installed any kde-based software, you could end up with
-a kde-enabled kvirc installation: you probably want to avoid that.
+a kde-enabled KVIrc installation: you probably want to avoid that.
To sum these suggestion up, this is my current cmake invocation:
cmake .. -DWANT_KDE4=0 -DWANT_DEBUG=1 -DWANT_QTDBUS=0 -DWANT_PYTHON=0 -DWANT_PERL=0
---
-Notes for ppc/386 archs:
+Notes for ppc/386 arch:
---
* If you want to use Perl (Documentation and Modules) you have to build a
universal binary. This is due to Cmake overriding your architecture values
@@ -114,9 +114,9 @@ used by Apple when they built the python package.
I suggest an "out-of-source" build:
- # mkdir kvirc-build
- # cd kvirc-build
- # cmake <path-to-kvirc-src-dir>
+ # mkdir release
+ # cd release
+ # cmake ..
# make
# make install
diff --git a/doc/INSTALL-Win32.txt b/doc/INSTALL-Win32.txt
index 7929237c6..a1e2ae035 100644
--- a/doc/INSTALL-Win32.txt
+++ b/doc/INSTALL-Win32.txt
@@ -6,7 +6,6 @@ This paper describes how to successfully compile a working copy of KVIrc 4.x
under Microsoft Windows operating systems.
-
-------------------------------------------------------------------------------
Prerequisites
-------------------------------------------------------------------------------
@@ -15,9 +14,9 @@ Prerequisites
[Needed to run KVIrc into, mandatory]
- - xp or 2003 server, preferably with at least service pack 2
- - vista, preferably not :p
- - seven or 2008 server
+ - XP or 2003 server, preferably with at least service pack 2
+ - Vista, preferably not :p
+ - Seven or 2008 server
Notice: DOS-based Windows operating systems (95,98,se,me) are not officially
supported by KVIrc. Anyway, if you're still using such an old OS then you
@@ -25,7 +24,7 @@ Prerequisites
Notice: Windows 2000 may work, but is not officially supported anymore.
Differences in its network stack and the difficulty to retrieve packages
- of kvirc dependencies still working on win2000 make compiling kvirc an
+ of KVIrc dependencies still working on win2000 make compiling KVIrc an
overkill job.
- CMake from Kitware
@@ -74,7 +73,7 @@ Prerequisites
You want the "Free Community Edition" package.
Perl is needed to extract documentation from the source files and generate
- help files for kvirc.
+ help files for KVIrc.
Some perl releases misses dmake; if you get a strange error at compilation
time, run the following command from cmd prompt (start->run->cmd):
@@ -93,7 +92,7 @@ Prerequisites
Search them on the MinGW project files download page.
- Install the lib somewhere (like c:\zlib) and remember its path.
+ Install the lib somewhere (like C:\zlib) and remember its path.
- OpenSSL compiled for Win32
@@ -108,7 +107,7 @@ Prerequisites
Newer OpenSSL versions from www.slproweb.com need a specific version of
Microsoft Visual Studio 2008 runtimes to work (this sucks): so if you plan
- to create a redistributable kvirc package, our advice is to compile
+ to create a redistributable KVIrc package, our advice is to compile
OpenSSL by yourself using MinGW/MSYS and then use your libs.
To compile OpenSSL by yourself:
@@ -120,7 +119,7 @@ Prerequisites
- enter in the created directory
- run "./config shared"
- run "make" and then "make install"
- - grab the entire installation directory (eg: C:\MinGW\msys\1.0\local\ssl)
+ - grab the entire installation directory (e.g. C:\MinGW\msys\1.0\local\ssl)
and copy it in a more accessible path (like C:\OpenSSL)
Whatever way you choose, install OpenSSL somewhere (like C:\OpenSSL)
@@ -140,29 +139,29 @@ Prerequisites
- GNU GetText for Win32
- [Localization tools; needed to translate kvirc interface into your
+ [Localization tools; needed to translate KVIrc interface into your
own language; required if you're building a redistributable package,
otherwise optional]
We advice you to use the version you can find at
http://gnuwin32.sourceforge.net/packages/gettext.htm,
follow the "Setup program" link.
- Install the package somewhere (like c:\gettext) and remember the path.
+ Install the package somewhere (like C:\gettext) and remember the path.
- GNU Sed for Win32
- [Tool; needed to tidy kvirc translation files, optional]
+ [Tool; needed to tidy KVIrc translation files, optional]
We advice you to use the version you can find at
http://gnuwin32.sourceforge.net/packages/sed.htm,
follow the "Setup program" link.
- Install the package somewhere (like c:\sed) and remember the path.
+ Install the package somewhere (like C:\sed) and remember the path.
-- Subversion cli for windows
+- Git for windows
- [Versioning tool; needed for cmake to automatically set the correct
- revision number in kvirc build; can be overridden (see below)]
+ [Git; is needed for cmake to automatically set the correct
+ revision number in KVIrc build; can be overridden (see below)]
Any version will work; Recently the subversion guys went nuts and despite
an official download page exists http://subversion.apache.org/packages.html
@@ -171,12 +170,12 @@ Prerequisites
If you don't want to install subversion cli because you are already using
another subversion tool (like TortoiseSvn), you can just force the correct
- svn revision passing to cmake the -DMANUAL_REVISION=xxxx parameter.
+ Git revision passing to cmake the -DMANUAL_REVISION=xxxx parameter.
- Nullsoft scriptable install system (NSIS)
[Installer packages creator; needed if you want to create an installer
- package for kvirc]
+ package for KVIrc]
Get it at http://nsis.sourceforge.net/Download ; the package you want
is called "nsis-2.46-setup.exe" (version numbers may vary).
@@ -184,7 +183,7 @@ Prerequisites
-------------------------------------------------------------------------------
-Further reccomended download if you plan to develop KVIrc:
+Further recommended download if you plan to develop KVIrc:
-------------------------------------------------------------------------------
- GNU Debugger (gdb) for Win32:
@@ -229,7 +228,7 @@ Run the win32_run_cmake.bat script.
# win32_run_cmake.bat
-This should invoke the cmake executable and configure kvirc for you.
+This should invoke the cmake executable and configure KVIrc for you.
If it complains about missing libraries then you haven't properly
edited the paths in the win32_run_cmake.bat file. Check again.
@@ -238,10 +237,10 @@ Note that the "bin" subdirectories generally aren't included in the path.
You may also try to use the CMake gui for the compilation. Just be aware
of the %PATH% variable defined in the win32_run_cmake.bat script. If you
screw up %PATH% CMake may refuse to start or the mingw make may crash.
-Note also that you must tell the graphical configurator that you want
+Note also that you must tell the graphical configuration that you want
the "MinGW Makefiles" as output.
-Once cmake did its job (it will tell you that it's ready to compile kvirc)
+Once cmake did its job (it will tell you that it's ready to compile KVIrc)
you can just run the mingw make program.
# mingw32-make.exe
@@ -252,22 +251,22 @@ If it runs without errors then you can also run make install:
# mingw32-make.exe install
-This should create a working kvirc executable for you in the build\release
+This should create a working KVIrc executable for you in the build\release
directory. With some experience you may also get mingw to create a debug
build.
-Simply running kvirc from that directory should work :) . If instead it's
-complaining of some missing dll's, you may need to copy those dlls into
- kvirc binary directory (in our example: c:\KVirc\build\release) or to get
+Simply running KVIrc from that directory should work :) . If instead it's
+complaining of some missing dlls, you may need to copy those dlls into
+ KVIrc binary directory (in our example: C:\KVirc\build\release) or to get
those dlls recognized and loaded automatically from your OS.
If you want to create an installer package, you need to:
-1) fill the binary directory (in our example: c:\KVIrc\build\release) with
+1) fill the binary directory (in our example: C:\KVIrc\build\release) with
all the files that cmake doesn't create:
- needed dlls:
- Qt: QtCore4, QtGui4 (mandatory); QtNetwork4, QtSvg4, QtWebkit4,
- QtXml, QtXmlPatterns (used in objects module);
+ QtXml, QtXmlPatterns (used in objects module);
- Zlib: libz.dll (aka libz-1.dll, zlib.dll, ...);
- Openssl: libeay32.dll, libssl32.dll (names may vary);
- MinGW: mingwm10.dll, libgcc_s_dw2-1.dll
@@ -275,39 +274,39 @@ If you want to create an installer package, you need to:
- Python: python26.dll (version number may vary);
- Amip: ac.dll / ac.ini (adds plug'n'play support for amip)
Choose the right dlls depending on your build options: for a debug
- build you'll need debug version of Qt libraries (eg. QtCored4)
+ build you'll need debug version of Qt libraries (e.g. QtCored4)
- qt plugins:
These have to be placed in a subdirectory named qt-plugins
- (in our example: c:\KVirc\build\release\qt-plugins).
+ (in our example: C:\KVirc\build\release\qt-plugins).
Currently KVIrc can use 4 types of plugins: codecs, imageformats,
phonon_backend, sqldrivers. Create a subdirectory and name it with the
type name of the plugins you'll place inside it;
- (eg: c:\KVirc\build\release\qt-plugins\imageformats\qjpeg4.dll)
+ (e.g. C:\KVirc\build\release\qt-plugins\imageformats\qjpeg4.dll)
You can find them inside the "plugins" directory in the Qt Sdk.
Choose the right dlls depending on your build options: for a debug
- build you'll need debug version of Qt plugins (eg. qjpegd4.dll)
+ build you'll need debug version of Qt plugins (e.g. qjpegd4.dll)
- locale translations:
If you did not install or disabled gettext, your release folder misses
- the "locale" folder tipically containing translation files. This means
- kvirc won't be able to translate its user interface.
+ the "locale" folder typically containing translation files. This means
+ KVIrc won't be able to translate its user interface.
As a workaround, you can get translation files somewhere, create the
"locale" folder and manually place translations inside it.
- help file:
If you did not install or disabled perl, your release folder misses
- the "help" folder tipically containing user help. This means
- kvirc internal help will contain no help pages.
+ the "help" folder typically containing user help. This means
+ KVIrc internal help will contain no help pages.
As a workaround, you can get help files somewhere, create the
"help/en" folder and manually place help files inside it.
-2) run the KVIrc.nsi script from the build directory (c:\kvirc\build in our example) .
+2) run the KVIrc.nsi script from the build directory (C:\kvirc\build in our example) .
Just compile it using nsis and an installer package will be generated.
-------------------------------------------------------------------------------
-Common errors, pitfalls, ..
+Common errors, pitfalls,
-------------------------------------------------------------------------------
- On modules compilation we get a warning like this one:
@@ -324,4 +323,7 @@ Common errors, pitfalls, ..
that warning simply means that moc found nothing to expand in that header file. We can fix this
removing headers that doesn't need to be moc-ed from the lists in CMakeLists.txt.
-- * Windows Vista and 7 Users * If you have UAC enabled (default setting) and KVIrc is installed in the Program Files folder and you have opted to use the portable setting, then KVIrc's data files will be found in the VirtualStore folder, typically: C:\Users\[UserName]\AppData\Local\VirtualStore\Program Files\KVIrc\ If you plan on using the portable setting, it is recommended that you install KVIrc in a non UAC protected folder.
+- * Windows Vista and 7 Users * If you have UAC enabled (default setting) and KVIrc is installed in the Program Files folder
+ and you have opted to use the portable setting, then KVIrc's data files will be found in the VirtualStore folder,
+ typically: C:\Users\[UserName]\AppData\Local\VirtualStore\Program Files\KVIrc\ If you plan on using the portable setting,
+ it is recommended that you install KVIrc in a non UAC protected folder.
diff --git a/doc/accelerator.keys.txt b/doc/accelerator.keys.txt
index bff3e359e..5398bcb24 100644
--- a/doc/accelerator.keys.txt
+++ b/doc/accelerator.keys.txt
@@ -1,6 +1,6 @@
This is a comprehensive list of all accelerator keys defined in KVIrc.
An accelerator key is a combination of keyboard buttons that, when pressed
-toghether, will accomplish an action which otherwise would be done by moving
+together, accomplish an action which otherwise would be achieved by moving
the mouse or selecting from a menu.
Some notes on keys:
@@ -9,7 +9,7 @@ Under Windows, the Ctrl+Alt is mapped to the AltGr (Alternative Graphics) key.
Since AltGr is used in many keyboard layouts to produce special characters,
the use of any Ctrl+Alt hotkey is discouraged.
A list of standard window hotkeys can be found here: http://support.microsoft.com/kb/126449
-Under Unix*/KDE, a lot of keys are globally binded to specific software, eg:
+Under Unix*/KDE, a lot of keys are globally binded to specific software, e.g.
Ctrl+Shift+S shows the contact list of Kopete
Ctrl+Alt+S stops the music player juk
A list of these can be found at SystemSettings->Keyboard and mouse->Global keyboard shortcuts.
@@ -20,7 +20,7 @@ F1 Help Index (Window)
Ctrl+A Select all
Ctrl+B Insert Bold control character
-Ctrl+C Copy to clipboard
+Ctrl+ Copy to clipboard
Ctrl+D
Ctrl+E
Ctrl+F Open "Find Text" dialog
@@ -36,7 +36,7 @@ Ctrl+O Insert Reset control character
Ctrl+P Insert "Plain text" control character
Ctrl+Q
Ctrl+R Insert Reverse control character
-Ctrl+S Open "Servers" dialog
+Ctrl+S Open "Servers" dialog
Ctrl+T Open "Manage Toolbars" dialog
Ctrl+U Insert Underline control character
Ctrl+V Paste clipboard contents
@@ -73,18 +73,17 @@ Ctrl+Shift+Y
Ctrl+Shift+Z
-
Window handling related keys:
-Alt+UpArrow: Previous window
+Alt+UpArrow Previous window
Alt+DownArrow: Next window
Alt+PageUp: Previous highlighted window
-Alt+PageDown: Next highlighted window
+Alt+PageDown Next highlighted window
Alt+Shift+UpArrow: Previous window in the same IRC context
Alt+Shift+DownArrow: Next window in the same IRC context
Ctrl+UpArrow: Maximizes current window
-Ctrl+DownArrow or ESC: Minimizes current window
-Shift+<F1-F12> window switch
+Ctrl+DownArrow / ESC: Minimizes current window
+Shift+<F1-F12> Window switch
PageUp: Scroll the output window up one page
PageDown: Scroll the output window down one page
Shift+PageUp: Scroll the output window up one line
@@ -92,47 +91,45 @@ Shift+PageDown: Scroll the output window down one line
Ctrl+W: Close current window
-
Text editing related hotkeys:
-Ctrl+LeftArrow: Selection left to the previous word
-Ctrl+RightArrow: Selection right to the next word
-Ctrl+Shift+LeftArrow: Previous word
-Ctrl+Shift+RightArrow: Next word
-Ctrl+<digit>: Script accelerators (see OnAccelKeyPressed)
-F2-F12, Shift+(F1-F12): Script accelerators (see OnAccelKeyPressed)
-Ctrl+B: Insert the 'bold' mIRC text control character
-Ctrl+K: Insert the 'color' mIRC text control character
-Ctrl+R: Insert the 'reverse' mIRC text control character
-Ctrl+U: Insert the 'underline' mIRC text control character
-Ctrl+O: Insert the 'reset' mIRC text control character
-Ctrl+P: Insert the 'non-crypt' (plain text) KVIrc control character used to disable encryption of the current text line
-Ctrl+C: Copie the selected text to clipboard
-Ctrl+X: Cut the selected text
-Ctrl+V: Paste the clipboard contents (same as middle mouse click)
-Ctrl+I: Insert the 'icon' control code and pops up the icon list box
-CursorUp: Move backward in the command history
-CursorDown: Move forward in the command history
-Ctrl+PageUp: Open the history popup
-CursorRight: Move the cursor to the right
-CursorLeft: Move the cursor to the left :)
-Shift+CursorLeft: Move the selection to the left
-Shift+RightCursor: Move the selection to the right
-Alt+Enter: Show/hide the multiline editor
-Ctrl+Enter: Send message as plain text, ignoring / commands
-Alt+<numeric_sequence>: Insert the character by ASCII/Unicode code; example:
- Alt+32: Inserts ASCII/Unicode character 32: ' ' (a space)
- Alt+00032: Same as above :)
- Alt+13: Inserts the Carriage Return (CR) control character
- Alt+77: Inserts ASCII/Unicode character 77: 'M'
- Alt+23566: Inserts Unicode character 23566 (an ideogram)
-
+Ctrl+LeftArrow: Selection left to the previous word
+Ctrl+RightArrow: Selection right to the next word
+Ctrl+Shift+LeftArrow: Previous word
+Ctrl+Shift+RightArrow: Next word
+Ctrl+<digit>: Script accelerators (see OnAccelKeyPressed)
+F2-F12, Shift+(F1-F12): Script accelerators (see OnAccelKeyPressed)
+Ctrl+B: Insert the 'bold' mIRC text control character
+Ctrl+K: Insert the 'color' mIRC text control character
+Ctrl+R: Insert the 'reverse' mIRC text control character
+Ctrl+U: Insert the 'underline' mIRC text control character
+Ctrl+O: Insert the 'reset' mIRC text control character
+Ctrl+P: Insert the 'non-crypt' (plain text) KVIrc control character used to disable encryption of the current text line
+Ctrl+C: Copy the selected text to clipboard
+Ctrl+X: Cut the selected text
+Ctrl+V: Paste the clipboard contents (same as middle mouse click)
+Ctrl+I: Insert the 'icon' control code and pops up the icon list box
+CursorUp: Move backward in the command history
+CursorDown: Move forward in the command history
+Ctrl+PageUp: Open the history popup
+CursorRight: Move the cursor to the right
+CursorLeft: Move the cursor to the left :)
+Shift+CursorLeft: Move the selection to the left
+Shift+RightCursor: Move the selection to the right
+Alt+Enter: Show/hide the multiline editor
+Ctrl+Enter: Send message as plain text, ignoring / commands
+Alt+<numeric_sequence> Insert the character by ASCII/Unicode code; example:
+Alt+32 Inserts ASCII/Unicode character 32: ' ' (a space)
+Alt+00032 Same as above :)
+Alt+13 Inserts the Carriage Return (CR) control character
+Alt+77 Inserts ASCII/Unicode character 77: 'M'
+Alt+23566 Inserts Unicode character 23566 (an ideogram)
Completion hotkeys
-Tab in the first word of input: Complete nicknames in the current channel or query
-Tab after a leading /: Complete commands
-Tab after a / in the middle of input: Complete directories
-Tab after a $: Complete function names
-Shift+Tab after the first word of input:Complete masks in the current channel or query
+Tab in the first word of input: Complete nicknames in the current channel or query
+Tab after a leading /: Complete commands
+Tab after a / in the middle of input: Complete directories
+Tab after a $: Complete function names
+Shift+Tab after the first word of input: Complete masks in the current channel or query
diff --git a/doc/addon.howto.txt b/doc/addon.howto.txt
index 2c83f227d..8224cf4eb 100644
--- a/doc/addon.howto.txt
+++ b/doc/addon.howto.txt
@@ -80,7 +80,7 @@ to create in order to package your addon and it usually looks like this:
The entries with a slash (/) at the end are directories while the other are files.
The toplevel directory should be named with your addon name and version. Use no spaces
-in the directory entries: this will make the things simplier for people that want to
+in the directory entries: this will make the things simpler for people that want to
use your addon.
The install.kvs is the mandatory initialization script which must contain all the
@@ -155,7 +155,7 @@ The "help" directory should contain subdirectories for each language your help f
are written in. The languages dirs should be named with the language code also used for
the translation files (like "en", "it" etc...).
-Please note that english is the default language and KVIrc will fallback to the "en"
+Please note that English is the default language and KVIrc will fallback to the "en"
subdirectory when no other language is found around...
@@ -201,7 +201,7 @@ There are also some switches that can be used to fiddle a little bit more :)
Each addon can have a help and a configuration callback. These are set respectively by
addon.sethelpcallback and addon.setconfigurecallback.
The help callback will be invoked by KVIrc when the user will ask help for your addon
-(mainly from the addon management dialog, but not necessairly). It should call help.open
+(mainly from the addon management dialog, but not necessarily). It should call help.open
with the name of your documentation index html file (it should be relative to the help
language directory.
@@ -212,7 +212,7 @@ A good and relatively complex addon *should* have at least a minimal help file e
the features.
The configuration callback will be invoked when the user will try to configure your addon
-from the addon management dialog. This callback is useful mainly for complexier graphical
+from the addon management dialog. This callback is useful mainly for more complex graphical
scripts that can show up a dialog that allows configuring all of the addon features.
To use this callback you will probably need some object scripting.
@@ -304,8 +304,9 @@ The name of the classes refer to the ones described above.
collisions with other scripts and addons.
- Remember that your addon is going to be installed on different platforms (at
- least linux, macosx and windows based). The poor windows' notepad has serious problems
- with reading text files that contain only linefeeds as line separators. Keep it in mind...
+ least Linux, Mac OS X and Windows based). The poor Windows' notepad has serious problems
+ with reading text files that contain only linefeeds as line separators.
+ You could consider using a proper editor like e.g. Notepad++
9. WHERE TO START
@@ -314,7 +315,7 @@ It is a good idea to start on the KVIrc web site. There are surely several addon
look at. Pick one that seems simple and analyze its layout and code (wow... the free
software!). It will be easier to do than it was to explain it :D
-Another great resource place is the IRC channel #KVIrc located on irc.freenode.org
+Another great resource place is the IRC channel #kvirc located on irc.freenode.org
network. There you can find many people able to code and help you.
Have fun! :)
diff --git a/doc/firefox.hack.txt b/doc/firefox.hack.txt
index 51f3a8469..9b31e63c1 100644
--- a/doc/firefox.hack.txt
+++ b/doc/firefox.hack.txt
@@ -17,16 +17,16 @@ This guide is been tested on Linux, Mac and Windows.
- Click with right button, select New, then String
As Name insert network.protocol-handler.app.irc
- As Value you have to insert the path of KVIrc binary, eg /usr/bin/kvirc,
+ As Value you have to insert the path of KVIrc binary, e.g. /usr/bin/kvirc,
`which kvirc` or C:\Programs\Firefox\firefox.exe
-- Make sure that network.protocol-handler.expose-all are setted as true
+- Make sure that network.protocol-handler.expose-all are set as true
With these simple steps you can handle irc://irc.something.tld from Firefox
If you want to add more protocols handlers, just follow the same steps changing
-the protocol you want to add in firefox and the application you want to use to
-handle the new protcol
+the protocol you want to add in Firefox and the application you want to use to
+handle the new protocol
Elvio Basello
<HelLViS69>
diff --git a/doc/hackers.guide.txt b/doc/hackers.guide.txt
index 06a64abec..d14b78430 100644
--- a/doc/hackers.guide.txt
+++ b/doc/hackers.guide.txt
@@ -617,7 +617,7 @@ In earlier KVIrc versions there was only KviConsole that did the role of both
KviConsole and KviIrcContext, but since the class has grown in complexity
to a point where it started to be unmantainable the splitting has been unavoidable.
-KviIrcConnection rappresents an IRC connection: it is the highest protocol
+KviIrcConnection represents an IRC connection: it is the highest protocol
implementation on the KVIrc's networking stack. A KviIrcConnection
owns a KviIrcLink (that is the lower level). KviIrcConnection is NOT reusable:
it lives only for the lifetime of a single IRC connection inside the parent
@@ -821,7 +821,7 @@ when the major number was bumped from N-1 to N. This usually also means
that the software might be somewhat incompatible with the previous major release.
When the major number is bumped up all the following parts are reset to 0
-(and could be even temporairly omitted).
+(and could be even temporarily omitted).
The second part is called minor release number and it is increased
more often than the major. A bump from N to N+1 in the minor version number
@@ -953,11 +953,11 @@ ones considered to be stable and released on the site in all the supported forms
in tracker sites and spread between distributors. Since "most" stable, the
official releases are the ones likely to be included in the OS distributions.
The official packages have md5 sums and a gpg signature of one of the KVIrc
-developers (with a public key available from a "trusteable" location such
+developers (with a public key available from a "trusted" location such
as the KVIrc web site).
The semi-official packages are snapshots of the source tree made when
-some important changes have occured. They are announced on the KVIrc site
+some important changes have occurred. They are announced on the KVIrc site
only and are likely to be stable (but are not declared officially to be so).
The semi-official packages usually are at least in the source form but
there are likely to be some binaries available too.
diff --git a/doc/translations.howto.txt b/doc/translations.howto.txt
index 16839f451..b231c6578 100644
--- a/doc/translations.howto.txt
+++ b/doc/translations.howto.txt
@@ -3,9 +3,9 @@ This mini-howto describes the procedure for translating KVIrc in a new language.
Step 0: Getting the right sources.
-First of all you need the SVN version of KVIrc.
-To obtain the SVN version you can follow the instructions on
-http://www.kvirc.net/?id=svn
+First of all you need the Git version of KVIrc.
+To obtain the Git version you can follow the instructions on
+http://www.kvirc.net/?id=git
The translation stuff is in kvirc/po .
@@ -69,13 +69,13 @@ step 3.
You can translate *.po files using a simple text editor (that _have_ to support
the UTF-8 encoding), but it's strongly advised that you use a translation software
-such as lokalize for linux/kde or poedit for windows.
+such as lokalize for Linux/KDE or poedit for Windows.
Note on the format of the translation files:
The *.po files contains a set of strings like the following one:
#: /path/to/the/file/which/contains/the/string: line number
-msgid "The original english message"
+msgid "The original English message"
msgstr "The translation goes here"
The msgid is the original message that needs to be translated
@@ -122,7 +122,7 @@ Step 7: Updating the translation when the sources change
In the process of KVIrc development, new message strings gets added inside the
source files, while some others can change or even get removed.
-When you do a svn update to obtain the latest sources you should then enter your
+When you do a Git update to obtain the latest sources you should then enter your
build directory and run:
# make messages-update
@@ -147,9 +147,10 @@ the procedure above may be repeated for the po/modules/*/ subdirectories.
Anyway you are not forced to translate all the files at once: a partial
translation will work anyway.
-When you're satisfied with your translation you may send your *.po files to the
-KVIrc mailing list asking for inclusion in the SVN. If you want to maintain the
-translation in the future then you may also apply for a SVN account.
+When you're satisfied with your translation you may send your pull request for the
+*.po files to KVIrc Github project https://github.com/kvirc/KVIrc or send the *.po
+to the KVIrc mailing list asking for inclusion in Git. If you want to maintain the
+translation in the future then you may also apply for a Github account.
Happy translating :)
diff --git a/po/core/kvirc/kvirc.pot b/po/core/kvirc/kvirc.pot
index a3fd75bac..a0350481b 100644
--- a/po/core/kvirc/kvirc.pot
+++ b/po/core/kvirc/kvirc.pot
@@ -3056,7 +3056,7 @@ msgid ""
"<b>Ooops...</b><br><br><b>There are some reasons that make me think that "
"your KVIrc installation is incomplete.</b><br><br>I might be wrong, but you "
"seem to miss some of the features that the default KVIrc script provides."
-"This may happen because you have upgraded to an unstable svn version, "
+"This may happen because you have upgraded to an unstable Git version, "
"because you have accidentally deleted or damaged your configuration files, "
"because you have installed an incomplete script or because you have hit a "
"bug in KVIrc.<br><br>I can repeat the installation of the default script in "
@@ -5942,7 +5942,7 @@ msgid "Check on startup"
msgstr ""
#: src/kvirc/ui/KviStatusBarApplet.cpp:664
-msgid "Check SVN revisions"
+msgid "Check Git revisions"
msgstr ""
#: src/kvirc/ui/KviStatusBarApplet.cpp:697
diff --git a/src/kvirc/kernel/KviApplication.cpp b/src/kvirc/kernel/KviApplication.cpp
index 62ae5a40d..6781f7544 100644
--- a/src/kvirc/kernel/KviApplication.cpp
+++ b/src/kvirc/kernel/KviApplication.cpp
@@ -1139,7 +1139,7 @@ void KviApplication::checkSuggestRestoreDefaultScript()
__tr2qs("<b>Ooops...</b><br><br>" \
"<b>There are some reasons that make me think that your KVIrc installation is incomplete.</b><br><br>" \
"I might be wrong, but you seem to miss some of the features that the default KVIrc script provides." \
- "This may happen because you have upgraded to an unstable svn version, " \
+ "This may happen because you have upgraded to an unstable Git version, " \
"because you have accidentally deleted or damaged your configuration files, " \
"because you have installed an incomplete script " \
"or because you have hit a bug in KVIrc.<br><br>" \
diff --git a/src/kvirc/ui/KviStatusBarApplet.cpp b/src/kvirc/ui/KviStatusBarApplet.cpp
index 80a3b6175..dc5dd5337 100644
--- a/src/kvirc/ui/KviStatusBarApplet.cpp
+++ b/src/kvirc/ui/KviStatusBarApplet.cpp
@@ -661,7 +661,7 @@ void KviStatusBarUpdateIndicator::fillContextPopup(QMenu * p)
pAction->setCheckable(true);
pAction->setChecked(m_bUpdateOnStartup);
- pAction = p->addAction(__tr2qs("Check SVN revisions"),this,SLOT(toggleRevision()));
+ pAction = p->addAction(__tr2qs("Check Git revisions"),this,SLOT(toggleRevision()));
pAction->setCheckable(true);
pAction->setChecked(m_bUpdateRevision);
}
@@ -704,7 +704,7 @@ void KviStatusBarUpdateIndicator::checkVersion()
QString szUrl,szFileName;
if(m_bUpdateRevision)
- szUrl = "http://kvirc.net/checkversion.php?svn=1";
+ szUrl = "http://kvirc.net/checkversion.php?git=1";
else
szUrl = "http://kvirc.net/checkversion.php";
@@ -786,7 +786,7 @@ void KviStatusBarUpdateIndicator::getNewVersion()
if(m_bUpdateRevision)
{
- szUrl = "https://svn.kvirc.de/kvirc/changeset/";
+ szUrl = "https://svn.kvirc.de/kvirc/changeset/"; // this needs a git URL probably to releases or something else.
szUrl += m_szNewVersion;
} else {
QString szSystem = KviBuildInfo::buildSystemName();
@@ -806,7 +806,7 @@ void KviStatusBarUpdateIndicator::getNewVersion()
QString szCommand = "openurl ";
szCommand += szUrl;
// Open the svn or the download page for the platform we're using
KviKvsScript::run(szCommand,g_pActiveWindow);
}
@@ -835,7 +835,7 @@ QString KviStatusBarUpdateIndicator::tipText(const QPoint &)
} else if(m_bUpdateStatus){
szRet += __tr2qs("New updates found");
szRet += "</b><br>";
- szRet += __tr2qs("Double click to get the lastest version");
+ szRet += __tr2qs("Double click to get the latest version");
}
szRet += "</center>";
return szRet;
@@ -806,7 +806,7 @@ void KviStatusBarUpdateIndicator::getNewVersion()
QString szCommand = "openurl ";
szCommand += szUrl;
- // Open the svn or the download page for the platform we're using
+ // Open the Git or the download page for the platform we're using
KviKvsScript::run(szCommand,g_pActiveWindow);
}